@@ -31,13 +31,13 @@ def discover_controllers(package):
             # TODO filter request functions
             # if len(args) == 0 or args[0] != 'request': continue
             
-            urls.append(url(name + '/(?P<resource_id>[^/\?\&]+)/' + member + '/?$', func))
-            urls.append(url(name + '/' + member + '/?$', func))
+            urls.append(url('^' + name + '/(?P<resource_id>[^/\?\&]+)/' + member + '/?$', func))
+            urls.append(url('^' + name + '/' + member + '/?$', func))
 
         if 'show' in dir(controller):
-            urls.append(url(name + '/(?P<resource_id>[^/\?\&]+)/?$', getattr(controller, 'show')))
+            urls.append(url('^' + name + '/(?P<resource_id>[^/\?\&]+)/?$', getattr(controller, 'show')))
         if 'index' in dir(controller):
-            urls.append(url(name + '$', getattr(controller, 'index')))
+            urls.append(url('^' + name + '$', getattr(controller, 'index')))
                 
     return include(urls)
 
